@@ -1,7 +1,6 @@
 # Copyright 2022 Rafe Kaplan
 # SPDX-License-Identifier: Apache-2.0
 #
-# Updated: 2022-05-30
 import contextlib
 import dataclasses
 import datetime
@@ -60,7 +59,7 @@ def _check_and_delete_mutually_exclusive(
 
 
 def iter_dir(dir: pathlib.Path) -> Iterator[pathlib.Path]:
-    for entry in dir.iterdir():
+    for entry in sorted(dir.iterdir()):
         if entry.is_symlink():
             continue
         if entry.is_dir():
@@ -116,13 +115,20 @@ def iter_path(path: pathlib.Path) -> Iterator[tuple[pathlib.Path, bool]]:
     count=True,
     help="Increase log verbosity. May be used more than once.",
 )
+@click.option(
+    "--show-changes",
+    is_flag=True,
+    default=False,
+    is_eager=True,
+    help="Show changes in header.",
+)
 @click.option(
     "--quiet",
     "-q",
     count=True,
     help="Decrease log verbosity. May be used more than once.",
 )
-def main(paths, check, delete, config_path, verbose, quiet):
+def main(paths, check, delete, config_path, verbose, show_changes, quiet):
     """
     Consistent header manager
 
@@ -193,6 +199,7 @@ def main(paths, check, delete, config_path, verbose, quiet):
                     values,
                     result.parsed_values,
                     delete,
+                    show_changes,
                 )
 
         if error:
